================================================
poppy: Physical Optics Propagation in PYthon
================================================

.. image:: https://pypip.in/v/poppy/badge.png
    :target: https://pypi.python.org/pypi/poppy

.. image:: https://pypip.in/d/poppy/badge.png
    :target: https://pypi.python.org/pypi/poppy


POPPY (Physical Optics Propagation in PYthon) is a Python package that
simulates physical optical propagation including diffraction. It implements a
flexible framework for modeling Fraunhofer (far-field) diffraction and point
spread function formation, particularly in the context of astronomical
telescopes. 

POPPY was developed as part of a simulation package for the James Webb Space
Telescope, but is more broadly applicable to many kinds of imaging simulations.
It is not, however, a substitute for fidelity physical optical
design software, but rather is intended as a lightweight alternative for cases
that don't require that much computational firepower. 


For documentation, see http://www.stsci.edu/~mperrin/software/poppy/


Most code by Marshall Perrin, with some contributions from 
Anand Sivaramakrishnan, Remi Soummer, Ewan Douglas, and others.



